@@ -1,11 +1,11 @@
 /* AstroChart.m
- * The well known circular Astrology chart
+ * The circular Astrology chart
  *
  * Copyright (C) 1998-2006 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1998-12-19
- * modified: 2006-05-05
+ * modified: 2006-07-29
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -166,6 +166,8 @@ static NSArray *colorWheel(float s)
 
 /*
  * Ecliptic circle: outside ring with global houses and signs
+ * radius1	outer radius of ring
+ * radius2	inner radius of ring
  */
 - (VGroup*)eclipticWithCenter:(NSPoint)center
                      radius1:(float)radius1 radius2:(float)radius2
@@ -403,7 +405,8 @@ typedef enum
     [layer addObject:group];
 }
 
-/* modified: 2006-04-15 (aspect lines added)
+/* calculate main chart
+ * modified: 2006-07-29
  */
 - (VGroup*)horoscopeWithCenter:(NSPoint)cp radius:(float)radius
                    tableOrigin:(NSPoint)tableOrigin
@@ -669,28 +672,33 @@ typedef enum
 
     /* title, date, city, lat, lng
      */
-    if (template && (text = [self textWithSubstring:@"#NAME#" fromTemplate:template]))
+    if (template && (text = [self textWithSubstring:@"#DATE#" fromTemplate:template]))
     {   NSMutableString	*string = [[[text string] mutableCopy] autorelease];
         NSRange		range;
         NSString	*ns, *ew;
 
         range = [string rangeOfString:@"#NAME#"];
-        [string replaceCharactersInRange:range withString:title];
+        if (range.length)
+            [string replaceCharactersInRange:range withString:title];
         range = [string rangeOfString:@"#DATE#"];
-        [string replaceCharactersInRange:range
-                              withString:[gmt descriptionWithCalendarFormat:dateFormat]];
+        if (range.length)
+            [string replaceCharactersInRange:range
+                                  withString:[gmt descriptionWithCalendarFormat:dateFormat]];
         range = [string rangeOfString:@"#LOCATION#"];
-        ns = (latitude  >= 0.0) ? @"N" : @"S";
-        ew = (longitude >= 0.0) ? @"E" : @"W";
-        if (Prefs_DegreesMinutes)
-            [string replaceCharactersInRange:range
-                                  withString:[NSString stringWithFormat:@"%@ %@ %@ %@ %@",
-                                      city, stringFromDeg(Abs(latitude)),  ns,
-                                            stringFromDeg(Abs(longitude)), ew]];
-        else
-            [string replaceCharactersInRange:range
-                                  withString:[NSString stringWithFormat:@"%@ %.3f %@, %.3f %@",
-                                      city, Abs(latitude), ns, Abs(longitude), ew]];
+        if (range.length)
+        {
+            ns = (latitude  >= 0.0) ? @"N" : @"S";
+            ew = (longitude >= 0.0) ? @"E" : @"W";
+            if (Prefs_DegreesMinutes)
+                [string replaceCharactersInRange:range
+                                      withString:[NSString stringWithFormat:@"%@ %@ %@ %@ %@",
+                                          city, stringFromDeg(Abs(latitude)),  ns,
+                                          stringFromDeg(Abs(longitude)), ew]];
+            else
+                [string replaceCharactersInRange:range
+                                      withString:[NSString stringWithFormat:@"%@ %.3f %@, %.3f %@",
+                                          city, Abs(latitude), ns, Abs(longitude), ew]];
+        }
         [text replaceTextWithString:string];
     }
     else
@@ -1020,6 +1028,7 @@ typedef enum
 
 /* draw composite chart inside chart
  * radius is the ouiter radius of the chart
+ * modified: 2006-07-29
  */
 - (VGroup*)compositeWithCenter:(NSPoint)cp radius:(float)radius
                       template:(NSArray*)template  color:(NSColor*)color title:(NSString*)title
@@ -1103,28 +1112,33 @@ typedef enum
         NSRect		r;
         float		viewWidth = [view bounds].size.width;
 
-        if (template && (text = [self textWithSubstring:@"#NAME_C#" fromTemplate:template]))
+        if (template && (text = [self textWithSubstring:@"#DATE_C#" fromTemplate:template]))
         {   NSMutableString	*string = [[[text string] mutableCopy] autorelease];
             NSRange		range;
             NSString		*ns, *ew;
 
             range = [string rangeOfString:@"#NAME_C#"];
-            [string replaceCharactersInRange:range withString:title];
+            if (range.length)
+                [string replaceCharactersInRange:range withString:title];
             range = [string rangeOfString:@"#DATE_C#"];
-            [string replaceCharactersInRange:range
-                                  withString:[gmt descriptionWithCalendarFormat:dateFormat]];
+            if (range.length)
+                [string replaceCharactersInRange:range
+                                      withString:[gmt descriptionWithCalendarFormat:dateFormat]];
             range = [string rangeOfString:@"#LOCATION_C#"];
-            ns = (latitude  >= 0.0) ? @"N" : @"S";
-            ew = (longitude >= 0.0) ? @"E" : @"W";
-            if (Prefs_DegreesMinutes)
-                [string replaceCharactersInRange:range
-                                      withString:[NSString stringWithFormat:@"%@ %@ %@ %@ %@",
-                                      city, stringFromDeg(Abs(latitude)),  ns,
-                                            stringFromDeg(Abs(longitude)), ew]];
-            else
-                [string replaceCharactersInRange:range
-                                      withString:[NSString stringWithFormat:@"%@ %.3f N, %.3f E",
-                                          city, latitude, longitude]];
+            if (range.length)
+            {
+                ns = (latitude  >= 0.0) ? @"N" : @"S";
+                ew = (longitude >= 0.0) ? @"E" : @"W";
+                if (Prefs_DegreesMinutes)
+                    [string replaceCharactersInRange:range
+                                          withString:[NSString stringWithFormat:@"%@ %@ %@ %@ %@",
+                                              city, stringFromDeg(Abs(latitude)),  ns,
+                                              stringFromDeg(Abs(longitude)), ew]];
+                else
+                    [string replaceCharactersInRange:range
+                                          withString:[NSString stringWithFormat:@"%@ %.3f N, %.3f E",
+                                              city, latitude, longitude]];
+            }
             [text replaceTextWithString:string];
         }
         else
@@ -1541,61 +1555,13 @@ typedef enum
     [view cache:NSZeroRect];
     [[NSNotificationCenter defaultCenter] postNotificationName:DocLayerListHasChanged object:view];
 }
-#if 0	// deprecated
-- (BOOL)getMarksFromTemplate:(NSArray*)list
-                      center:(NSPoint*)center
-                      radius:(float*)radius                        start:(NSPoint*)start
-             radiusComposite:(float*)radiusComposite      startComposite:(NSPoint*)startComposite
-                 tableOrigin:(NSPoint*)tableOrigin  tableOriginComposite:(NSPoint*)tableOriginC
-{   int		i, okNum = 0;
-    BOOL	okCenter = NO, okStart = NO, okStartC = NO, okTable = NO, okTableC = NO;
-
-    for (i=0; i<[list count]; i++)
-    {   VMark	*g = [list objectAtIndex:i];
-
-        if ([g isKindOfClass:[VMark class]])
-        {
-            if ([[g name] isEqual:@"CENTER"])
-            {   *center = [g origin]; okCenter = YES; }
-            else if ([[g name] isEqual:@"START"])
-            {
-                *start = [g origin];
-                *radius = sqrt( SqrDistPoints(*center, [g origin]) );
-                okStart = YES;
-            }
-            else if ([[g name] isEqual:@"START_C"])
-            {
-                *startComposite = [g origin];
-                *radiusComposite = sqrt( SqrDistPoints(*center, [g origin]) );
-                okStartC = YES;
-            }
-            else if ([[g name] isEqual:@"TABLE"])
-            {   *tableOrigin = [g origin]; okTable = YES; }
-            else if ([[g name] isEqual:@"TABLE_C"])
-            {   *tableOriginC = [g origin]; okTableC = YES; }
-            if ((++okNum) >= 5)
-                break;
-        }
-    }
-    if (!okCenter)
-        NSLog(@"Mark with name 'CENTER' missing on template layer");
-    if (!okStart)
-        NSLog(@"Mark with name 'START' missing on template layer");
-    if (!okStartC)
-        NSLog(@"Mark with name 'START_C' missing on template layer");
-    if (!okTable)
-        NSLog(@"Mark with name 'TABLE' missing on template layer");
-    if (!okTableC)
-        NSLog(@"Mark with name 'TABLE_C' missing on template layer");
-    return okCenter && okStart && okStartC && okTable && okTableC;
-}
-#endif
 
 /* read template
  * Marks:
  *   CENTER	center mark for chart
  *   CENTER_#	center of interval chart
- *   START	radius and start angle of chart
+ *   START	radius and start angle of chart (scale radius)
+ *   RADIUS	maximum radius of chart (ecliptical signs)
  *   START_#	radius and start angle of interval charts
  *   START_C	same for composite chart
  *   TABLE	table origin
@@ -1607,12 +1573,14 @@ typedef enum
  *   LOCATION
  *   DATE
  *   TIME_#	time text for interval chart, optinally with interval (-#, +# in minutes)
+ *
+ * modified: 2006-10-09
  */
 - (ChartTemplate)chartTemplate
 {
     return chartTemplate;
 }
-- (ChartTemplate)getGetTemplate:(NSArray*)list
+- (ChartTemplate)getTemplate:(NSArray*)list
 {   int		i, ix, maxInterval = MAX_CHARTINTERVALS;
     NSRange	range;
     VText	*text;
@@ -1621,6 +1589,7 @@ typedef enum
     chartTemplate.center = NSZeroPoint;
     chartTemplate.start  = chartTemplate.startC = NSZeroPoint;
     chartTemplate.radius = chartTemplate.radiusC = 0.0;
+    chartTemplate.radiusMax = 0.0;
     chartTemplate.table  = chartTemplate.tableC = NSZeroPoint;
     chartTemplate.info   = NSZeroPoint;
     for (i=0; i<maxInterval; i++)
@@ -1629,7 +1598,7 @@ typedef enum
         chartTemplate.startI[i]  = NSZeroPoint;
         chartTemplate.radiusI[i] = 0.0;
     }
-    chartTemplate.components = 0;
+    chartTemplate.components  = chartTemplate.componentsInt = 0;
     chartTemplate.layerMask   = -1;
     chartTemplate.layerChart  = -1;
     chartTemplate.layerMaskC  = -1;
@@ -1644,10 +1613,12 @@ typedef enum
                 chartTemplate.center = [g origin];
             else if ([[g name] isEqual:@"START"])
                 chartTemplate.start = [g origin];
-            else if ([[g name] isEqual:@"START_C"])
-                chartTemplate.startC = [g origin];
+            else if ([[g name] isEqual:@"RADIUS"])
+                chartTemplate.radiusMax = [g origin].x;
             else if ([[g name] isEqual:@"TABLE"])
                 chartTemplate.table = [g origin];
+            else if ([[g name] isEqual:@"START_C"])
+                chartTemplate.startC = [g origin];
             else if ([[g name] isEqual:@"TABLE_C"])
                 chartTemplate.tableC = [g origin];
             else if ([[g name] isEqual:@"INFO"])
@@ -1676,14 +1647,18 @@ typedef enum
         }
     }
 
-    text = [self textWithSubstring:@"#COMPONENTS" fromTemplate:list];
+    if (chartTemplate.radiusMax > 0.0)
+        chartTemplate.radiusMax -= chartTemplate.center.x;	// convert position to radius
+
+    text = [self textWithSubstring:@"#COMPONENTS:" fromTemplate:list];
     if (text)
     {   NSString	*string = [text string];
 
         chartTemplate.components = 0;
         if ([string rangeOfString:@"ZODIAC"].length)
             chartTemplate.components |= CHART_ZODIAC;
-        if ([string rangeOfString:@"SCALE"].length)
+        range = [string rangeOfString:@"SCALE"];
+        if (range.length && [string characterAtIndex:range.location-1] != 'O')
             chartTemplate.components |= CHART_SCALE;
         if ([string rangeOfString:@"OBJECTS"].length)
             chartTemplate.components |= CHART_OBJECTS;
@@ -1702,10 +1677,38 @@ typedef enum
     }
     else
     {
-        if ( DiffPoint(chartTemplate.center, NSZeroPoint) > 0.0 )
-            chartTemplate.components = 0xFFFFFF;	// all components
+        if ( DiffPoint(chartTemplate.center, NSZeroPoint) > 0.0 )	// template exists
+            chartTemplate.components = CHART_ALL;	// all components
     }
 
+    text = [self textWithSubstring:@"#COMPONENTS_INT" fromTemplate:list];
+    if (text)
+    {   NSString	*string = [text string];
+
+        chartTemplate.componentsInt = 0;
+        if ([string rangeOfString:@"ZODIAC"].length)
+            chartTemplate.componentsInt |= CHART_ZODIAC;
+        range = [string rangeOfString:@"SCALE"];
+        if (range.length && [string characterAtIndex:range.location-1] != 'O')
+            chartTemplate.componentsInt |= CHART_SCALE;
+        if ([string rangeOfString:@"OBJECTS"].length)
+            chartTemplate.componentsInt |= CHART_OBJECTS;
+        if ([string rangeOfString:@"ASPECTLINES"].length)
+            chartTemplate.componentsInt |= CHART_ASPECTLINES;
+        if ([string rangeOfString:@"DECLINATION"].length)
+            chartTemplate.componentsInt |= CHART_DECLINATION;
+        if ([string rangeOfString:@"HOUSES"].length)
+            chartTemplate.componentsInt |= CHART_HOUSES;
+        if ([string rangeOfString:@"TOPOSCALE"].length)
+            chartTemplate.componentsInt |= CHART_TOPOSCALE;
+        if ([string rangeOfString:@"STAR"].length)
+            chartTemplate.componentsInt |= CHART_STAR;
+        if ([string rangeOfString:@"WAVE"].length)
+            chartTemplate.componentsInt |= CHART_WAVE;
+    }
+    else
+        chartTemplate.componentsInt = chartTemplate.components;	// same components
+
     /* layer indexe */
     text = [self textWithSubstring:@"#LAYERS" fromTemplate:list];
     if (text)
@@ -1743,18 +1746,20 @@ typedef enum
     /* no template -> set default values */
     if (!templateOK)
     {
-        chartTemplate.center  = NSMakePoint(296.0, 535.0);
-        chartTemplate.radius  = 204.0;
-        chartTemplate.radiusC = 144.0;
-        chartTemplate.table   = NSMakePoint(20.0, 37.0);
-        chartTemplate.tableC  = NSMakePoint(573.0, 37.0);
-        chartTemplate.components = 0xFFFFFF;	// all components
+        chartTemplate.center     = NSMakePoint(296.0, 535.0);
+        chartTemplate.radiusMax  = 204.0 * RADIUS_1;
+        chartTemplate.radius     = 204.0 * RADIUS_2;
+        chartTemplate.radiusC    = 204.0 * RADIUS_3;
+        chartTemplate.table      = NSMakePoint( 20.0, 37.0);
+        chartTemplate.tableC     = NSMakePoint(573.0, 37.0);
+        chartTemplate.components = chartTemplate.componentsInt = CHART_ALL;	// all components
     }
 
     return chartTemplate;
 }
 
-/* modified: 2006-06-03
+/* main calculation method
+ * modified: 2006-07-29
  */
 - (void)radix:(NSCalendarDate*)gmt
     longitude:(float)longitude latitude:(float)latitude
@@ -1807,12 +1812,12 @@ typedef enum
         ixComposite = 3;
     }
     template = [[layerList objectAtIndex:ixTemplate] list];
-    chartTemplate = [self getGetTemplate:template];
+    chartTemplate = [self getTemplate:template];
 
     /* shortcuts */
-    cp = chartTemplate.center;
-    radius  = chartTemplate.radius;
-    radiusC = chartTemplate.radiusC;
+    cp           = chartTemplate.center;
+    radius       = chartTemplate.radius;
+    radiusC      = chartTemplate.radiusC;
     tableOrigin  = chartTemplate.table;
     tableOriginC = chartTemplate.tableC;
     if (chartTemplate.layerMask   >= 0 && chartTemplate.layerMask   < [layerList count])
@@ -1850,35 +1855,37 @@ typedef enum
 
     /* no mask -> calculate basics
      */
-    if (ixMaskRadix < 0)		// calculate basics
-    {
+    {   //maskLayer = (ixMaskRadix) ? [layerList objectAtIndex:ixMaskRadix] : layer;
+
         /* center star */
-        if (chartTemplate.components & CHART_CENTER)
+        if (ixMaskRadix < 0 && chartTemplate.components & CHART_CENTER)
             [layer addObject:[self starWithCenter:cp radius:radius*STAR_SIZE rotate:rotateAC]];
 
         /* Ecliptic circle: global houses and signs */
-        if (chartTemplate.components & CHART_ZODIAC)
+        if ( (ixMaskRadix < 0 || chartTemplate.components != CHART_ALL)
+             && chartTemplate.components & CHART_ZODIAC )
             [layer addObject:[self eclipticWithCenter:cp
-                                              radius1:radius*RADIUS_1 radius2:radius*RADIUS_2
+                                              radius1:chartTemplate.radiusMax radius2:radius
                                            symbolSize:radius*SYMBOL_SIZE rotate:rotateAC]];
 
         /* scale */
-        if (chartTemplate.components & CHART_SCALE)
-            [layer addObject:[self scaleWithCenter:cp radius:radius*RADIUS_2
+        if ( (ixMaskRadix < 0 || chartTemplate.components != CHART_ALL)
+             && chartTemplate.components & CHART_SCALE )
+            [layer addObject:[self scaleWithCenter:cp radius:radius
                                         scaleSize1:radius*SCALE_MIN scaleSize2:radius*SCALE_MAX
                                         degreeType:SCALEDEG_360 rotate:rotateAC]];
     }
     /* rotate AC to the left
      * we create a rotated copy of the mask and turn off the mask
      */
-    else if (rotateAC)	// rotate Mask
+    if (ixMaskRadix >= 0 && rotateAC)	// rotate Mask
     {   NSArray	*list = [[layerList objectAtIndex:ixMaskRadix] list];
 
         [[layerList objectAtIndex:ixMaskRadix] setState:0];
         for (i=0; i<(int)[list count]; i++)
         {   VGraphic	*g = [[[list objectAtIndex:i] copy] autorelease];
 
-            if (![g isLocked])
+            if (![[list objectAtIndex:i] isLocked])	// check original, for copy loses the lock !
             {   [g setAngle:-rotateAC withCenter:cp];
                 if ([g isKindOfClass:[VText class]] && [(VText*)g isSerialNumber])
                     [g rotate:[g rotAngle]];
@@ -1886,7 +1893,7 @@ typedef enum
             [layer addObject:g];
         }
     }
-    else		// no rotation -> enable mask
+    else if (ixMaskRadix >= 0)		// no rotation -> enable mask
         [[layerList objectAtIndex:ixMaskRadix] setState:1];
 
     g = [self horoscopeWithCenter:cp radius:radius tableOrigin:tableOrigin
@@ -1915,18 +1922,34 @@ typedef enum
     /* Create Interval Chart
      */
     if ( DiffPoint(chartTemplate.centerI[0], NSZeroPoint) > 0.0 )
-    {   int	i;
-        int	min = Prefs_AstroInterval;
+    {   int		i;
+        int		min = Prefs_AstroInterval, minMinutes = 999999;
+        NSString	*strFormat;
+        VText		*text;
+
+        /* find min interval = base interval */
+        if (min != 0)
+        {
+            for (i=0; DiffPoint(chartTemplate.centerI[i], NSZeroPoint) > 0.0; i++)
+            {
+                strFormat = [NSString stringWithFormat:@"#TIME_%d", i+1];
+                if ( (text = [self textWithSubstring:strFormat fromTemplate:template]) )
+                {   int	minutes;
+
+                    minutes = [[[text string] substringFromIndex:[strFormat length]] intValue];
+                    if (minutes != 0 && Abs(minutes) < minMinutes)
+                        minMinutes = Abs(minutes);
+                }
+            }
+        }
 
         for (i=0; DiffPoint(chartTemplate.centerI[i], NSZeroPoint) > 0.0; i++)
-        {   NSString		*strFormat;
-            NSCalendarDate	*dateI = gmt;
+        {   NSCalendarDate	*dateI = gmt;
             NSPoint		cp;
             float		rad;
-            VText		*text;
 
-            cp    = chartTemplate.centerI[i];
-            rad   = chartTemplate.radiusI[i];
+            cp  = chartTemplate.centerI[i];
+            rad = chartTemplate.radiusI[i];
 
             strFormat = [NSString stringWithFormat:@"#TIME_%d", i+1];
             if ( (text = [self textWithSubstring:strFormat fromTemplate:template]) )
@@ -1934,12 +1957,17 @@ typedef enum
 
                 minutes = [[[text string] substringFromIndex:[strFormat length]] intValue];
                 if (min != 0 && minutes != 0)	// override interval from prefs
-                    minutes = (minutes>0) ? min : -min;
+                {   float f = (minutes) ? Max((Abs(minutes)/minMinutes), 1.0) : 1.0;
+                    minutes = f * ((minutes>0) ? min : -min);
+                }
                 dateI = [gmt dateByAddingYears:0 months:0 days:0 hours:0 minutes:minutes seconds:0];
                 [text replaceTextWithString:[dateI descriptionWithCalendarFormat:@"%H:%M"]];
                 [layer addObject:text];
             }
 
+            if ( min > 10 )	// delta > 10 minutes -> calculate objects
+                [ephemeris objectDictAtUTC:dateI lat:latitude lon:longitude elev:0.0
+                               topocentric:Prefs_Topocentric];
             [infoDict setObject:dateI                          forKey:@"date"];
             [infoDict setObject:propertyListFromNSPoint(cp)    forKey:@"center"];
             [infoDict setObject:[NSNumber numberWithFloat:rad] forKey:@"radius"];
@@ -1952,7 +1980,7 @@ typedef enum
     }
 
     /* composite */
-    if ( [composite intForKey:@"doCalculate"] )
+    if ( [composite intForKey:@"doCalculate"] && ixComposite >= 0)
     {   NSCalendarDate	*gmtH = gmt;	// save date of outside chart for composite table
 
         layer = [layerList objectAtIndex:ixComposite];
@@ -1968,48 +1996,57 @@ typedef enum
         if (Prefs_ACFix)
             rotateAC = 180.0 - ac(sideralTime(gmt, [composite floatForKey:@"lon"]), [composite floatForKey:@"lat"]);
 
-        if (ixMaskComposite < 0)	// calculate basics
         {   NSMutableArray	*list;
             VPath		*path;
             VArc		*arc;
 
             /* filled ring */
-            path = [VPath path];
-            [path setFillColor:GRAY_COLOR];
-            [path setFilled:YES optimize:NO];
-            list = [path list];
-            arc = [VArc arc];
-            [arc setCenter:cp start:NSMakePoint(cp.x+radius*RADIUS_3, cp.y) angle:360.0];
-            [list addObject:arc];
-            arc = [VArc arc];
-            [arc setCenter:cp start:NSMakePoint(cp.x+radius*RADIUS_4, cp.y) angle:360.0];
-            [list addObject:arc];
-            [layer addObject:path];
+            if ( ixMaskComposite < 0 && chartTemplate.components & CHART_ZODIAC )
+            {
+                path = [VPath path];
+                [path setFillColor:GRAY_COLOR];
+                [path setFilled:YES optimize:NO];
+                list = [path list];
+                arc = [VArc arc];
+                [arc setCenter:cp start:NSMakePoint(cp.x+radius*RADIUS_3, cp.y) angle:360.0];
+                [list addObject:arc];
+                arc = [VArc arc];
+                [arc setCenter:cp start:NSMakePoint(cp.x+radius*RADIUS_4, cp.y) angle:360.0];
+                [list addObject:arc];
+                [layer addObject:path];
+            }
 
             /* black border */
-            arc = [VArc arc];
-            [arc setCenter:cp start:NSMakePoint(cp.x+radius*RADIUS_3, cp.y) angle:360.0];
-            [layer addObject:arc];
-            arc = [VArc arc];
-            [arc setCenter:cp start:NSMakePoint(cp.x+radius*RADIUS_4, cp.y) angle:360.0];
-            [layer addObject:arc];
+            if ( (ixMaskComposite < 0 || chartTemplate.components != CHART_ALL)
+                 && chartTemplate.components & CHART_ZODIAC )
+            {
+                arc = [VArc arc];
+                [arc setCenter:cp start:NSMakePoint(cp.x+radius*RADIUS_3, cp.y) angle:360.0];
+                [layer addObject:arc];
+                arc = [VArc arc];
+                [arc setCenter:cp start:NSMakePoint(cp.x+radius*RADIUS_4, cp.y) angle:360.0];
+                [layer addObject:arc];
+            }
 
             /* scale */
-            [layer addObject:[self scaleWithCenter:cp radius:radius*RADIUS_3
-                                        scaleSize1:radius*SCALE_MIN scaleSize2:radius*SCALE_MAX
-                                        degreeType:SCALEDEG_NONE rotate:rotateAC]];
+            if ( (ixMaskComposite < 0 || chartTemplate.components != CHART_ALL)
+                 && chartTemplate.components & CHART_SCALE )
+            {   [layer addObject:[self scaleWithCenter:cp radius:radius*RADIUS_3
+                                            scaleSize1:radius*SCALE_MIN scaleSize2:radius*SCALE_MAX
+                                            degreeType:SCALEDEG_NONE rotate:rotateAC]];
+            }
         }
         /* rotate AC to the left
          * we create a rotated copy of the mask and turn off the mask
          */
-        else if (rotateAC)	// rotate Mask
+        if (ixMaskComposite >= 0  && rotateAC)	// rotate Mask
         {   NSArray	*list = [[layerList objectAtIndex:ixMaskComposite] list];
 
             [[layerList objectAtIndex:ixMaskComposite] setState:0];
             for (i=0; i<(int)[list count]; i++)
             {   VGraphic	*g = [[[list objectAtIndex:i] copy] autorelease];
 
-                if (![g isLocked])
+                if (![[list objectAtIndex:i] isLocked])
                 {   [g setAngle:-rotateAC withCenter:cp];
                     if ([g isKindOfClass:[VText class]] && [(VText*)g isSerialNumber])
                         [g rotate:[g rotAngle]];
@@ -2017,7 +2054,7 @@ typedef enum
                 [layer addObject:g];
             }
         }
-        else			// no rotation -> enable mask
+        else if (ixMaskComposite >= 0)		// no rotation -> enable mask
             [[layerList objectAtIndex:ixMaskComposite] setState:1];
 
         /* add composite chart */
