@@ -1,10 +1,10 @@
 /* AstroPanel.h
  *
- * Copyright (C) 1999-2005 by vhf interservice GmbH
+ * Copyright (C) 1999-2006 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * Created:  1995-08-10
- * Modified: 2005-09-04
+ * Modified: 2006-01-08
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -33,6 +33,7 @@
 #define AP_CHART	0
 #define AP_MAP		1
 #define AP_SEARCH	2
+#define AP_FLOWCHART	3
 #define AP_DEFAULT	99
 
 #define BUTTONLEFT	0
@@ -59,11 +60,12 @@
     NSScrollView	*levView;
 #endif
 
-    id			windows[10];
     int			levelCnt;
+    id			windows[10];
     id			chartWindow;
     id			mapWindow;
     id			searchWindow;
+    id			flowWindow;
 
     id			activeWindow;
     BOOL		tabEvent;
