@@ -1,11 +1,11 @@
 /*
  * AstroPanel.m
  *
- * Copyright 1999-2005 by vhf interservice GmbH
+ * Copyright 1999-2006 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * Created:  1995-08-10
- * Modified: 2005-09-13
+ * Modified: 2006-02-01
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -28,8 +28,9 @@
 
 #include <VHFShared/vhfCommonFunctions.h>
 #include <VHFShared/VHFSystemAdditions.h>
-#include "AstroPanel.h"
+#include "../AstroPrincipal.h"
 #include "../astroMessages.h"
+#include "AstroPanel.h"
 #include "APBasicLevel.h"
 #if ! USE_TABVIEW	// OpenStep
 #    include "../Cenon/UITabActionCell.subproj/UITabActionCell.h"
@@ -55,7 +56,7 @@
                              object:nil];
 
     item = [[NSTabViewItem alloc] initWithIdentifier:@"Chart"];
-    [item setLabel:@"Chart"];
+    [item setLabel:TABCHART_STRING];
     [item setView:[[self windowAt:AP_CHART] contentView]];
     [tabView addTabViewItem:item];
     windows[levelCnt] = activeWindow = chartWindow;
@@ -75,6 +76,13 @@
     windows[levelCnt] = searchWindow;
     levelCnt++;
 
+    /*item = [[NSTabViewItem alloc] initWithIdentifier:@"FlowChart"];
+    [item setLabel:TABFLOWCHART_STRING];
+    [item setView:[[self windowAt:AP_FLOWCHART] contentView]];
+    [tabView addTabViewItem:item];
+    windows[levelCnt] = flowWindow;
+    levelCnt++;*/
+
     return self;
 }
 
@@ -87,25 +95,7 @@
      */
     if ( !setSubLevel )
     {
-        if ( [[tabViewItem identifier] isEqual:@"Chart"] && activeWindow != chartWindow )
-        {
-            [activeWindow displayWillEnd];
-            [tabViewItem setView:[[self windowAt:AP_CHART] contentView]];
-            activeWindow = chartWindow;
-        }
-        else if ( [[tabViewItem identifier] isEqual:@"Map"] && activeWindow != mapWindow )
-        {
-            [activeWindow displayWillEnd];
-            [tabViewItem setView:[[self windowAt:AP_MAP] contentView]];
-            activeWindow = mapWindow;
-        }
-        else if ( [[tabViewItem identifier] isEqual:@"Search"] && activeWindow != searchWindow )
-        {
-            [activeWindow displayWillEnd];
-            [tabViewItem setView:[[self windowAt:AP_SEARCH] contentView]];
-            activeWindow = searchWindow;
-        }
-        else if (level < levelCnt)
+        if ( level < levelCnt && activeWindow != windows[level] )
         {
             [activeWindow displayWillEnd];
             [tabViewItem setView:[[self windowAt:level] contentView]];
@@ -145,6 +135,8 @@
 - init
 {   NSNotificationCenter	*notificationCenter = [NSNotificationCenter defaultCenter];
 
+    [super init];
+
     /* add observer to add tabs */
     [notificationCenter addObserver:self
                            selector:@selector(addTabNotification:)
@@ -217,33 +209,44 @@
         case AP_CHART:
             if ( !chartWindow )
             {	if (![NSBundle loadModelNamed:@"APChart" owner:self])
-                    NSLog(@"Cannot load APChart model");
+                    NSLog(@"Cannot load APChart interface");
+                windows[level] = chartWindow;
                 [[chartWindow init] setWindow:self];
                 [[chartWindow contentView] retain];	// GNUstep
-                windows[AP_CHART] = chartWindow;
             }
             return chartWindow;
         case AP_MAP:
             if ( !mapWindow )
             {	if (![NSBundle loadModelNamed:@"APMap" owner:self])
-                    NSLog(@"Cannot load APMap model");
+                    NSLog(@"Cannot load APMap interface");
+                windows[level] = mapWindow;
                 [[mapWindow init] setWindow:self];
                 [[mapWindow contentView] retain];	// GNUstep
-                windows[AP_MAP] = mapWindow;
             }
             return mapWindow;
         case AP_SEARCH:
             if ( !searchWindow )
             {	if (![NSBundle loadModelNamed:@"APSearch" owner:self])
-                    NSLog(@"Cannot load APSearch model");
+                    NSLog(@"Cannot load APSearch interface");
+                windows[level] = searchWindow;
                 [[searchWindow init] setWindow:self];
                 [[searchWindow contentView] retain];	// GNUstep
-                windows[AP_SEARCH] = searchWindow;
             }
             return searchWindow;
+        /*case AP_FLOWCHART:
+            if ( !flowWindow )
+            {	if (![NSBundle loadModelNamed:@"APFlowChart" owner:self])
+                    NSLog(@"Cannot load APFlowChart interface");
+                windows[level] = flowWindow;
+                break;
+            }
+            return windows[level];*/
         default:
             return (level < levelCnt) ? windows[level] : nil;
     }
+    [[windows[level] init] setWindow:self];
+    [[windows[level] contentView] retain];	// GNUstep
+    return windows[level];
 }
 
 /*
@@ -284,6 +287,13 @@
 }
 
 
+/* delegate methods
+ */
+- (void)windowDidBecomeKey:(NSNotification*)notification
+{
+    [activeWindow update:self];
+}
+
 /*
  * Notifications
  */
@@ -294,6 +304,7 @@
 
     windows[level] = [panel retain];
     levelCnt ++;
+    [panel init];	// ???
     [panel setWindow:self];
     [[panel contentView] retain];	// GNUstep
 
@@ -315,7 +326,7 @@
         size = [levelRadio bounds].size;
         [levelRadio setCellSize:NSMakeSize(size.width/levelCnt, size.height)];
         [self display];
-        [self flushWindow]; 
+        [self flushWindow];
     }
 #endif
 }
