@@ -5,7 +5,7 @@
  * Author:   Georg Fleischmann
  *
  * created:  2003-03-29
- * modified: 2006-05-13
+ * modified: 2006-07-15
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -114,15 +114,52 @@ NSString *stringFromDeg(float deg)
 
 
 /* init
+ * modified: 2006-07-15
  */
 - init
 {   NSNotificationCenter	*notificationCenter = [NSNotificationCenter defaultCenter];
+    NSFileManager		*fileManager = [NSFileManager defaultManager];
 #if !defined(GNUSTEP_BASE_VERSION) && !defined(__APPLE__)	// OpenStep 4.2
     NSMenu			*toolMenu = [[[NSApp mainMenu] itemWithTag:MENU_TOOLS] target];
 #else
     NSMenu			*toolMenu = [[[NSApp mainMenu] itemAtIndex:MENU_TOOLS-1] submenu];
 #endif
 
+    /* create HOME-Library entries, if they doesn't exist */
+    if ( ![fileManager fileExistsAtPath:localLibrary()] )	// no Cenon master library!
+        NSRunAlertPanel(@"", CANTFINDLIB_STRING, OK_STRING, nil, nil, NULL);
+    else
+    {   NSString	*path = userLibrary(), *from = nil, *to, *dir = nil, *folder;
+        int		i;
+
+        /* create "Cenon/Astro" */
+        to = vhfPathWithPathComponents(path, MODULENAME, nil);
+        if ( ![fileManager fileExistsAtPath:to] )
+            [fileManager createDirectoryAtPath:to attributes:nil];
+
+        /* create folders + copy "Cenon/Astro/.../.dir.tiff" */
+        for (i=0; i<3; i++)
+        {
+            switch (i)
+            {
+                case 0:
+                    from = vhfPathWithPathComponents(localLibrary(), MODULENAME, @".dir.tiff", nil);
+                    dir  = vhfPathWithPathComponents(path, MODULENAME, nil);
+                    to   = vhfPathWithPathComponents(dir, @".dir.tiff", nil);
+                    break;
+                case 1: folder = @"Charts";
+                case 2: if (i == 2) folder = @"Maps";
+                    from = vhfPathWithPathComponents(localLibrary(), MODULENAME, folder, @".dir.tiff", nil);
+                    dir  = vhfPathWithPathComponents(path, MODULENAME, folder, nil);
+                    to   = vhfPathWithPathComponents(dir, @".dir.tiff", nil);
+            }
+            if ( dir && ![fileManager fileExistsAtPath:dir] )
+                [fileManager createDirectoryAtPath:dir attributes:nil];
+            if ( ![fileManager fileExistsAtPath:to] )
+                [fileManager copyPath:from toPath:to handler:nil];
+        }
+    }
+
     /* add observer for documents that open */
     [notificationCenter addObserver:self
                            selector:@selector(documentDidOpen:)
