@@ -635,8 +635,11 @@ static int indexFromType(NSString *typeString)
             {   NSMutableDictionary	*dataDict;
 
                 dataDict = [NSMutableDictionary dictionaryWithContentsOfFile:filePath];
-                [folders addObject:file];
-                [extEventDict setObject:dataDict forKey:file];
+                if (dataDict)
+                {
+                    [folders addObject:file];
+                    [extEventDict setObject:dataDict forKey:file];
+                }
             }
         }
     }
