@@ -422,7 +422,7 @@ double vhfSideralTimeMJD(double mjd, float lon)
 }
 
 
-/* Julian day (starting -4712)
+/* Julian day from Calendar Date (starting -4712)
  */
 double vhfJulianDay(NSCalendarDate *date)
 {   int		year, month, day;
@@ -450,6 +450,65 @@ double vhfJulianDay(NSCalendarDate *date)
     return jd;
 }
 
+/* Julian day (starting -4712)
+ */
+double vhfJulianDayFromInt(int yyyymmdd, int hhmm)
+{   int		year, month, day;
+    double	hour, y0, y1, jd;
+
+    year  = yyyymmdd / 10000;
+    yyyymmdd -= yyyymmdd/10000*10000;
+    month = yyyymmdd / 100;
+    yyyymmdd -= yyyymmdd/100*100;
+    day   = yyyymmdd;
+    hour  = (double)hhmm/100 + (double)(hhmm-(hhmm/100*100))/60.0;
+
+    if ( month <= 2 )
+    {   month += 12;
+        year--;
+    }
+    y0 = year;
+    jd = floor((y0+4712.0)*365.25) + floor(30.6*(month+1.0)+0.000001) + day + hour/24.0 - 63.5;
+
+    y1 = Abs(year)/100 - Abs(year)/400;
+    if (year < 0)
+        y1 = -y1;
+    jd = jd - y1 + 2.0;
+    if ((year < 0) && (y0/100.0 == floor(y0/100.0)) && (y0/400.0 != floor(y0/400.0)))
+        jd -= 1.0;
+
+    return jd;
+}
+/* date from Julian day (starting -4712)
+ */
+int vhfIntDateFromJulianDay(double jd, int *yyyymmdd, int *hhmm)
+{   int		year, month, day, yymmdd;
+    double	u0, u1, u2, u3, u4, hour;
+
+    u0 = jd + 32082.5;
+    u1 = u0 + floor(u0/36525.0) - floor(u0/146100.0) - 38.0;
+    if (jd >= 1830691.5)
+        u1 += 1;
+    u0 = u0 + floor(u1/36525.0) - floor(u1/146100.0) - 38.0;
+
+    u2 = floor(u0 + 123.0);
+    u3 = floor((u2 - 122.2) / 365.25);
+    u4 = floor((u2 - floor(365.25 * u3) ) / 30.6001);
+    month = (int)(u4 - 1.0);
+    if (month > 12)
+        month -= 12;
+    day   = (int) (u2 - floor(365.25 * u3) - floor(30.6001 * u4));
+    year  = (int) (u3 + floor((u4 - 2.0) / 12.0) - 4800);
+    hour  = (jd - floor(jd + 0.5) + 0.5) * 24.0;
+
+    yymmdd = year*10000 + month*100 + day;
+    if (yyyymmdd)
+        *yyyymmdd = yymmdd;
+    if (hhmm)
+        *hhmm   = (int)hour*100 + (int)(hour/60.0);
+    return yymmdd;
+}
+
 /* gmt to local time
  * start at 22.09. 00:00 UTC
  * each 24h (86400s) +4 minutes (star day = 23:56:04.1) -> +235.9 sec
